Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/artemis_sg/__init__.py | 4 | 0 | 0 | 0 | 0 | 100%
src/artemis_sg/_version.py | 2 | 2 | 0 | 0 | 0 | 0%
src/artemis_sg/app_creds.py | 27 | 7 | 0 | 8 | 1 | 71%
src/artemis_sg/cli.py | 208 | 44 | 2 | 120 | 18 | 79%
src/artemis_sg/config/__init__.py | 49 | 26 | 0 | 22 | 2 | 44%
src/artemis_sg/gcloud.py | 61 | 43 | 2 | 12 | 0 | 25%
src/artemis_sg/img_downloader.py | 93 | 11 | 2 | 34 | 7 | 86%
src/artemis_sg/item.py | 48 | 1 | 0 | 16 | 1 | 97%
src/artemis_sg/items.py | 91 | 9 | 0 | 34 | 4 | 90%
src/artemis_sg/scraper.py | 677 | 132 | 0 | 110 | 29 | 78%
src/artemis_sg/slide_generator.py | 288 | 47 | 0 | 50 | 14 | 80%
src/artemis_sg/spreadsheet.py | 299 | 41 | 0 | 98 | 16 | 84%
src/artemis_sg/vendor.py | 27 | 3 | 0 | 8 | 3 | 83%
Total | 1874 | 366 | 6 | 512 | 95 | 78%

No items found using the specified filter.